@@ -3,25 +3,21 @@ use std::io::{self, Write};
 use byteorder::{LittleEndian, WriteBytesExt};
 
 use super::sam_record::NULL_QUALITY_SCORE;
-use crate::Record;
+use crate::{record::ReferenceSequenceId, Record};
 
 pub(super) fn write_record<W>(writer: &mut W, record: &Record) -> io::Result<()>
 where
     W: Write,
 {
-    use crate::record::reference_sequence_id;
-
     let block_size = u32::try_from(record.block_size())
         .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?;
     writer.write_u32::<LittleEndian>(block_size)?;
 
-    let ref_id = record
-        .reference_sequence_id()
-        .map(i32::from)
-        .unwrap_or(reference_sequence_id::UNMAPPED);
-    writer.write_i32::<LittleEndian>(ref_id)?;
+    // ref_id
+    write_reference_sequence_id(writer, record.reference_sequence_id())?;
 
-    writer.write_i32::<LittleEndian>(record.pos)?;
+    // pos
+    write_position(writer, record.pos)?;
 
     let l_read_name = u8::try_from(record.read_name.len())
         .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?;
@@ -43,13 +39,11 @@ where
         .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?;
     writer.write_u32::<LittleEndian>(l_seq)?;
 
-    let next_ref_id = record
-        .mate_reference_sequence_id()
-        .map(i32::from)
-        .unwrap_or(reference_sequence_id::UNMAPPED);
-    writer.write_i32::<LittleEndian>(next_ref_id)?;
+    // next_ref_id
+    write_reference_sequence_id(writer, record.mate_reference_sequence_id())?;
 
-    writer.write_i32::<LittleEndian>(record.next_pos)?;
+    // next_pos
+    write_position(writer, record.next_pos)?;
 
     writer.write_i32::<LittleEndian>(record.template_length())?;
 
@@ -86,6 +80,27 @@ where
     Ok(())
 }
 
+fn write_reference_sequence_id<W>(
+    writer: &mut W,
+    reference_sequence_id: Option<ReferenceSequenceId>,
+) -> io::Result<()>
+where
+    W: Write,
+{
+    use crate::record::reference_sequence_id::UNMAPPED;
+
+    let ref_id = reference_sequence_id.map(i32::from).unwrap_or(UNMAPPED);
+    writer.write_i32::<LittleEndian>(ref_id)
+}
+
+// pos is 0-based.
+fn write_position<W>(writer: &mut W, pos: i32) -> io::Result<()>
+where
+    W: Write,
+{
+    writer.write_i32::<LittleEndian>(pos)
+}
+
 #[cfg(test)]
 mod tests {
     use noodles_sam as sam;
@@ -138,7 +153,7 @@ mod tests {
         record.pos = 8; // 0-based
         *record.mapping_quality_mut() = MappingQuality::from(13);
         *record.bin_mut() = 6765;
-        *record.flags_mut() = Flags::PAIRED | Flags::READ_1;
+        *record.flags_mut() = Flags::SEGMENTED | Flags::FIRST_SEGMENT;
         *record.mate_reference_sequence_id_mut() = record.reference_sequence_id();
         record.next_pos = 21; // 0-based
         *record.template_length_mut() = 144;
